@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/auth/cellconfig.c,v 1.1.1.8 2001/07/16 07:16:46 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/auth/cellconfig.c,v 1.1.1.10 2001/09/20 06:12:38 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <afs/pthread_glock.h>
@@ -191,10 +191,15 @@ register struct afsconf_dir *adir; {
 static afsconf_Touch(adir)
 register struct afsconf_dir *adir; {
     char tbuffer[256];
+#ifndef AFS_NT40_ENV
     struct timeval tvp[2];
+#endif
+
+    adir->timeRead = 0;	/* just in case */
 
 #ifdef AFS_NT40_ENV
     /* NT client CellServDB has different file name than NT server or Unix */
+
     if (IsClientConfigDirectory(adir->name)) {
 	strcompose(tbuffer, 256,
 		   adir->name, "/", AFSDIR_CELLSERVDB_FILE_NTCLIENT, NULL);
@@ -202,14 +207,11 @@ register struct afsconf_dir *adir; {
 	strcompose(tbuffer, 256,
 		   adir->name, "/", AFSDIR_CELLSERVDB_FILE, NULL);
     }
+
+    return _utime(tbuffer, NULL);
+
 #else
     strcompose(tbuffer, 256, adir->name, "/", AFSDIR_CELLSERVDB_FILE, NULL);
-#endif /* AFS_NT40_ENV */
-
-    adir->timeRead = 0;	/* just in case */
-#ifdef AFS_NT40_ENV
-    return _utime(tbuffer, NULL);
-#else
     gettimeofday(&tvp[0], NULL);
     tvp[1] = tvp[0];
     return utimes(tbuffer, tvp);
@@ -224,7 +226,7 @@ register char *adir; {
     LOCK_GLOBAL_MUTEX
     /* zero structure and fill in name; rest is done by internal routine */
     tdir = (struct afsconf_dir *) malloc(sizeof(struct afsconf_dir));
-    bzero(tdir, sizeof(struct afsconf_dir));
+    memset(tdir, 0, sizeof(struct afsconf_dir));
     tdir->name = (char *) malloc(strlen(adir)+1);
     strcpy(tdir->name, adir);
 
@@ -238,7 +240,7 @@ register char *adir; {
 	    /* The "AFSCONF" environment (or contents of "/.AFSCONF") will be typically set to something like "/afs/<cell>/common/etc" where, by convention, the default files for "ThisCell" and "CellServDB" will reside; note that a major drawback is that a given afs client on that cell may NOT contain the same contents... */
 	    char *home_dir;
 	    FILE *fp;
-	    int len;
+	    size_t len;
 
 	    if (!(home_dir = getenv("HOME"))) {
 		/* Our last chance is the "/.AFSCONF" file */
@@ -401,7 +403,7 @@ char clones[];
 		curEntry = 0;
 	    }
 	    curEntry = (struct afsconf_entry *) malloc(sizeof(struct afsconf_entry));
-	    bzero(curEntry, sizeof(struct afsconf_entry));
+	    memset(curEntry, 0, sizeof(struct afsconf_entry));
 	    code = ParseCellLine(tbuffer, curEntry->cellInfo.name, linkedcell);
 	    if (code) {
 		afsconf_CloseInternal(adir);
@@ -557,7 +559,8 @@ afsconf_GetAfsdbInfo(acellName, aservice, acellInfo)
     struct afsconf_cell *acellInfo;
 {
     afs_int32 code;
-    int tservice, len, i;
+    int tservice, i;
+    size_t len;
     unsigned char answer[1024];
     unsigned char *p;
     char host[256];
@@ -654,7 +657,8 @@ struct afsconf_cell *acellInfo; {
     register afs_int32 i;
     int tservice;
     char *tcell;
-    int cnLen, ambig;
+    size_t cnLen;
+    int ambig;
     char tbuffer[64];
 
     LOCK_GLOBAL_MUTEX
@@ -781,7 +785,7 @@ register struct afsconf_dir *adir; {
     if (adir->keystr) free(adir->keystr);
 
     /* reinit */
-    bzero(adir, sizeof(struct afsconf_dir));
+    memset(adir, 0, sizeof(struct afsconf_dir));
     adir->name = tname;	    /* restore it */
     return 0;
 }
@@ -858,7 +862,7 @@ struct afsconf_keys *astr;
     code = afsconf_Check(adir);
     if (code)
 	return AFSCONF_FAILURE;
-    bcopy(adir->keystr, astr, sizeof(struct afsconf_keys));
+    memcpy(astr, adir->keystr, sizeof(struct afsconf_keys));
     UNLOCK_GLOBAL_MUTEX
     return 0;
 }
@@ -892,7 +896,7 @@ afs_int32 afsconf_GetLatestKey(adir, avno, akey)
 	}
     }
     if (bestk) {    /* found any  */
-	if (akey) bcopy(bestk->key, akey, 8); /* copy out latest key */
+	if (akey) memcpy(akey, bestk->key, 8); /* copy out latest key */
 	if (avno) *avno = bestk->kvno;	/* and kvno to caller */
 	UNLOCK_GLOBAL_MUTEX
 	return 0;
@@ -919,7 +923,7 @@ char *akey;
 
     for(tk = adir->keystr->key,i=0;i<maxa;i++,tk++) {
 	if (tk->kvno == avno) {
-	    bcopy(tk->key, akey, 8);
+	    memcpy(akey, tk->key, 8);
 	    UNLOCK_GLOBAL_MUTEX
 	    return 0;
 	}
@@ -938,7 +942,7 @@ struct afsconf_dir *adir;
     register afs_int32 i;
     char tbuffer[256];
 
-    bcopy(adir->keystr, &tkeys, sizeof(struct afsconf_keys));
+    memcpy(&tkeys, adir->keystr, sizeof(struct afsconf_keys));
 
     /* convert it to net byte order */
     for(i = 0; i<tkeys.nkeys; i++ )
@@ -996,7 +1000,7 @@ char akey[8];
 	tkey = &tk->key[tk->nkeys++];
     }
     tkey->kvno = akvno;
-    bcopy(akey, tkey->key, 8);
+    memcpy(tkey->key, akey, 8);
     i = SaveKeys(adir);
     afsconf_Touch(adir);
     UNLOCK_GLOBAL_MUTEX
@@ -1032,7 +1036,7 @@ afs_int32 akvno;
     /* otherwise slide the others down.  i and tkey point at the guy to delete */
     for(;i<tk->nkeys-1; i++,tkey++) {
 	tkey->kvno = (tkey+1)->kvno;
-	bcopy((tkey+1)->key, tkey->key, 8);
+	memcpy(tkey->key, (tkey+1)->key, 8);
     }
     tk->nkeys--;
     i = SaveKeys(adir);
