@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/bozo/bos.c,v 1.1.1.6 2001/07/14 22:20:43 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/bozo/bos.c,v 1.1.1.8 2001/09/20 06:12:42 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <stdlib.h>
@@ -178,7 +178,7 @@ struct cmd_syndesc *as; {
 	printf("bos: can't find address for host '%s'\n", hostname);
 	exit(1);
     }
-    bcopy(th->h_addr, &addr, sizeof(afs_int32));
+    memcpy(&addr, th->h_addr, sizeof(afs_int32));
 
     /* get tokens for making authenticated connections */
     localauth = (as->parms[ADDPARMOFFSET + 2].items != 0);
@@ -289,7 +289,7 @@ afs_int32 alen; {
     register char *tp;
 
     strcpy(aresult, adir);
-    tp = rindex(aname, '/');
+    tp = strrchr(aname, '/');
     if (!tp) {
 	/* no '/' in name */
 	strcat(aresult, "/");
@@ -387,6 +387,7 @@ register struct cmd_syndesc *as; {
 	    printf("\n");
 	}
     }
+    return 0;
 }
 
 static UnInstall(as)
@@ -785,7 +786,7 @@ register struct cmd_syndesc *as; {
     char buf[BUFSIZ], ver[BUFSIZ];
     
     tconn = GetConn(as, 1);
-    bzero(&tkey, sizeof(struct ktc_encryptionKey));
+    memset(&tkey, 0, sizeof(struct ktc_encryptionKey));
 
 	if(as->parms[1].items)
 		strcpy(buf,as->parms[1].items->data);
@@ -1350,7 +1351,7 @@ struct cmd_syndesc *as; {
     char *orphans;
     char *tp;
 
-    bzero(&mrafsParm, sizeof(mrafsParm));
+    memset(&mrafsParm, 0, sizeof(mrafsParm));
     
     /* parm 0 is machine name, 1 is partition, 2 is volume, 3 is -all flag */
     tconn = GetConn(as, 0);
@@ -1791,8 +1792,8 @@ main(argc, argv)
     afsconf_SawCell = 0;	/* Reset it */
     /* don't check error code, since fails sometimes when we're setting up a
      * system */
-    initialize_cmd_error_table();
-    initialize_bz_error_table();
+    initialize_CMD_error_table();
+    initialize_BZ_error_table();
 
     ts = cmd_CreateSyntax("start", StartServer, 0, "start running a server");
     cmd_AddParm(ts, "-server", CMD_SINGLE, 0, "machine name");
