@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/butc/tcmain.c,v 1.1.1.4 2001/07/14 22:21:07 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/butc/tcmain.c,v 1.1.1.6 2001/09/20 06:12:57 hartmans Exp $");
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -838,20 +838,20 @@ char *arock; {
     debugLevel = 0;
 
     /*initialize the error tables */
-    initialize_ka_error_table();
-    initialize_rxk_error_table();
-    initialize_ktc_error_table();
-    initialize_acfg_error_table();
-    initialize_cmd_error_table();
-    initialize_vl_error_table();
-    initialize_butm_error_table();
-    initialize_butc_error_table();
+    initialize_KA_error_table();
+    initialize_RXK_error_table();
+    initialize_KTC_error_table();
+    initialize_ACFG_error_table();
+    initialize_CMD_error_table();
+    initialize_VL_error_table();
+    initialize_BUTM_error_table();
+    initialize_BUTC_error_table();
 #ifdef xbsa
-    initialize_butx_error_table();
+    initialize_BUTX_error_table();
 #endif /*xbs*/
-    initialize_vols_error_table();
-    initialize_budb_error_table();
-    initialize_bucd_error_table();
+    initialize_VOLS_error_table();
+    initialize_BUDB_error_table();
+    initialize_BUCD_error_table();
 
     if (as->parms[0].items)
     {
@@ -1165,7 +1165,7 @@ char **argv;
      */
     if (argc == 1) {
 	ts = (struct cmd_syndesc *) malloc(sizeof(struct cmd_syndesc));
-	bzero(ts, sizeof(*ts));
+	memset(ts, 0, sizeof(*ts));
 	
 	ti = (struct cmd_item *) malloc(sizeof(struct cmd_item));
 	ti->next = 0;
