@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/butm/butm_test.c,v 1.1.1.4 2001/07/14 22:21:09 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/butm/butm_test.c,v 1.1.1.6 2001/09/20 06:12:58 hartmans Exp $");
 
 #include <sys/types.h>
 #include <sys/file.h>
@@ -71,7 +71,7 @@ main (argc, argv)
     /* -------------
      * General Setup 
      * ------------- */
-    initialize_butm_error_table();
+    initialize_BUTM_error_table();
 
     tapeInfo.structVersion = BUTM_MAJORVERSION;
 
@@ -182,7 +182,7 @@ goto start;
     code = tapeInfo.ops.mount(&tapeInfo, "TAPE_NAME");
     PASSq ("Mount tape", 0);
 
-    bzero(tapeLabelWrite, sizeof(tapeLabelWrite));
+    memset(tapeLabelWrite, 0, sizeof(tapeLabelWrite));
     tapeLabelWrite.structVersion  = CUR_TAPE_VERSION;
     tapeLabelWrite.creationTime   = time(0);
     tapeLabelWrite.expirationDate = time(0);
@@ -201,7 +201,7 @@ goto start;
     code = tapeInfo.ops.readLabel(&tapeInfo, &tapeLabelRead, REWIND);
     PASS ("Read a label", 0);
 
-    if ( bcmp(&tapeLabelWrite, &tapeLabelRead, sizeof(tapeLabelWrite)) )
+    if ( memcmp(&tapeLabelWrite, &tapeLabelRead, sizeof(tapeLabelWrite)) )
         printf("FAILURE: Label Read is not same as label Written\n");
     else
         printf("PASSED: Label Read is same as label Written\n");
