@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/butm/test_ftm.c,v 1.1.1.4 2001/07/14 22:21:10 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/butm/test_ftm.c,v 1.1.1.6 2001/09/20 06:13:00 hartmans Exp $");
 
 #include <sys/types.h>
 #include <fcntl.h>
@@ -114,7 +114,7 @@ main (argc, argv)
     TestInfo ti;
 
     whoami = argv[0];
-    initialize_butm_error_table();
+    initialize_BUTM_error_table();
     if (argc < 2) 
       goto usage;
 
@@ -220,7 +220,7 @@ int PerformDumpTest(TestInfo *tip)
     ERROR_EXIT (2);
   }
   
-  bzero(&label, sizeof(label));
+  memset(&label, 0, sizeof(label));
   gettimeofday(&tp, 0);
   label.structVersion = CUR_TAPE_VERSION;
   label.creationTime = tp.tv_sec;
@@ -355,14 +355,14 @@ int PerformDumpTest(TestInfo *tip)
     
     tprogress = tlen = fprogress = flen = 0;
     while (1) {
-      bzero(tbuffer,BUTM_BLKSIZE);
+      memset(tbuffer, 0, BUTM_BLKSIZE);
       code = butm_ReadFileData (&info, tbuffer, BUTM_BLKSIZE, &tlen);
       
       if (code && code != BUTM_STATUS_EOF) {
 	com_err (whoami, code, "Reading %dth tape data", i+1);
 	ERROR_EXIT(6);
       }
-      bzero(fbuffer,BUTM_BLKSIZE);
+      memset(fbuffer, 0, BUTM_BLKSIZE);
       flen = read (fid, fbuffer, sizeof(fbuffer));
       if (flen < 0) {
 	com_err (whoami, errno, "Reading %dth file data", i+1);
