@@ -14,18 +14,19 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/des/read_pssword.c,v 1.1.1.5 2001/07/14 22:21:37 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/des/read_pssword.c,v 1.1.1.7 2001/09/20 06:13:27 hartmans Exp $");
 
 #include <mit-cpyright.h>
 #include <des.h>
 #include "conf.h"
 
 #include <stdio.h>
-#if defined(HAVE_STRINGS_H)
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#ifdef HAVE_STRINGS_H
 #include <strings.h>
 #endif
-#if defined(HAVE_STRING_H)
-#include <string.h>
 #endif
 
 #ifdef	BSDUNIX
@@ -61,7 +62,7 @@ static int intrupt;
 #endif
 
 static int intrupt;
-#if defined(AFS_SGI_ENV) || defined (AFS_AIX_ENV) || defined(AFS_FBSD_ENV) /*|| defined (AFS_HPUX_ENV) || defined(AFS_SUN5_ENV)*/
+#if defined(AFS_SGI_ENV) || defined (AFS_AIX_ENV) || defined(AFS_XBSD_ENV) /*|| defined (AFS_HPUX_ENV) || defined(AFS_SUN5_ENV)*/
 #undef	BSDUNIX
 #endif
 
@@ -107,11 +108,11 @@ des_read_password(k,prompt,verify)
 #ifdef BSDUNIX
 lose:
 #endif
-    bzero(key_string, sizeof (key_string));
+    memset(key_string, 0, sizeof (key_string));
     return ok;
 }
 
-#if	defined	(AFS_AIX_ENV) || defined (AFS_HPUX_ENV) || defined(AFS_SGI_ENV) || defined(AFS_SUN_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if	defined	(AFS_AIX_ENV) || defined (AFS_HPUX_ENV) || defined(AFS_SGI_ENV) || defined(AFS_SUN_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 static void catch(int);
 #endif
 
@@ -133,12 +134,12 @@ des_read_pw_string(s,maxa,prompt,verify)
 {
     int ok = 0, cnt1=0;
     char *ptr;
-#if defined(AFS_HPUX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_HPUX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     register int fno;
     struct sigaction newsig, oldsig;
     struct termios save_ttyb, ttyb;
 #endif
-#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     FILE *fi;
 #endif
 #if	defined(AFS_SUN_ENV) && !defined(AFS_SUN5_ENV)
@@ -171,7 +172,7 @@ des_read_pw_string(s,maxa,prompt,verify)
 	return -1;
     }
 
-#if defined(AFS_HPUX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_HPUX_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     if ((fi = fopen("/dev/tty", "r")) == NULL)
         return -1;
     setbuf(fi, (char *)NULL);			/* We don't want any buffering for our i/o. */
@@ -215,7 +216,7 @@ des_read_pw_string(s,maxa,prompt,verify)
 #else
 #ifdef	BSDUNIX
     /* XXX assume jmp_buf is typedef'ed to an array */
-    bcopy((char *)old_env, (char *)env, sizeof(env));
+    memcpy((char *)env, (char *)old_env, sizeof(env));
     if (setjmp(env))
 	goto lose;
     /* save terminal state*/
@@ -223,7 +224,7 @@ des_read_pw_string(s,maxa,prompt,verify)
 	return -1;
     push_signals();
     /* Turn off echo */
-    bcopy (&tty_state, &echo_off_tty_state, sizeof (tty_state));
+    memcpy(&echo_off_tty_state, &tty_state, sizeof (tty_state));
     echo_off_tty_state.sg_flags &= ~ECHO;
     if (ioctl(0,TIOCSETP,(char *)&echo_off_tty_state) == -1)
 	return -1;
@@ -276,7 +277,7 @@ des_read_pw_string(s,maxa,prompt,verify)
 	    }
 	    continue;
 	}
-	if ((ptr = index(s, '\n')))
+	if ((ptr = strchr(s, '\n')))
 	    *ptr = '\0';
 #endif
 	if (verify) {
@@ -291,7 +292,7 @@ des_read_pw_string(s,maxa,prompt,verify)
 		clearerr(stdin);
 		continue;
 	    }
-            if ((ptr = index(key_string, '\n')))
+            if ((ptr = strchr(key_string, '\n')))
 	    *ptr = '\0';
 #endif
 	    if (strcmp(s,key_string)) {
@@ -307,9 +308,9 @@ des_read_pw_string(s,maxa,prompt,verify)
 lose:
 #endif
     if (!ok)
-	bzero(s, maxa);
+	memset(s, 0, maxa);
     printf("\n");
-#if defined(AFS_HPUX_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_HPUX_ENV) || defined(AFS_XBSD_ENV)
     /*
      * Restore the terminal to its previous characteristics.
      * Restore the old signal handler for SIGINT.
@@ -338,7 +339,7 @@ lose:
     if (ioctl(0,TIOCSETP,(char *)&tty_state))
 	ok = 0;
     pop_signals();
-    bcopy((char *)env, (char *)old_env, sizeof(env));
+    memcpy((char *)old_env, (char *)env, sizeof(env));
 #else
 #if	defined	(AFS_AIX_ENV) /*|| defined (AFS_HPUX_ENV)*/ || defined(AFS_SGI_ENV) || defined(AFS_LINUX20_ENV)
     ttyb.c_lflag = flags;
@@ -361,7 +362,7 @@ lose:
 #endif
 #endif
     if (verify)
-	bzero(key_string, sizeof (key_string));
+	memset(key_string, 0, sizeof (key_string));
     s[maxa-1] = 0;		/* force termination */
     return !ok;			/* return nonzero if not okay */
 }
@@ -399,7 +400,7 @@ sig_restore()
 #endif
 
 
-#if	defined	(AFS_AIX_ENV) || defined (AFS_HPUX_ENV) || defined(AFS_SGI_ENV) || defined(AFS_SUN_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if	defined	(AFS_AIX_ENV) || defined (AFS_HPUX_ENV) || defined(AFS_SGI_ENV) || defined(AFS_SUN_ENV) || defined(AFS_LINUX20_ENV) || defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 static void
 catch(int junk)
 {
