@@ -10,8 +10,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/dir/buffer.c,v 1.1.1.4 2001/07/14 22:21:40 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/dir/buffer.c,v 1.1.1.6 2001/09/20 06:13:28 hartmans Exp $");
 
+#include <stdlib.h>
 #include <lock.h>
 
 #include "dir.h"
@@ -74,6 +75,7 @@ int DStat (abuffers, acalls, aios)
     {*abuffers = nbuffers;
     *acalls = calls;
     *aios = ios;
+    return 0;
     }
 
 int DInit (abuffers)
@@ -214,7 +216,7 @@ struct buffer *newslot (afid, apage, lp)
      register struct buffer *lp;   /* pointer to a fairly-old buffer */
     {/* Find a usable buffer slot */
     register afs_int32 i;
-    afs_int32 lt,pt;
+    afs_int32 lt;
     register struct buffer **tbp;
 
     if (lp && (lp->lockers == 0)) {
@@ -262,6 +264,7 @@ struct buffer *newslot (afid, apage, lp)
     return lp;
     }
 
+void
 DRelease (bp,flag)
     register struct buffer *bp;
     int flag;
