@@ -15,7 +15,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/krb_udp.c,v 1.1.1.8 2001/07/14 22:22:16 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/krb_udp.c,v 1.1.1.10 2001/09/20 06:15:00 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -85,12 +85,12 @@ char udptgsServerPrincipal[256];
 #define putstr(name) if ((slen = strlen(name)) >= MAXKTCNAMELEN) return -1;\
 		     else strcpy (answer, name), answer += slen+1
 #define putint(num) num = htonl(num), \
-		    bcopy (&num, answer, sizeof(afs_int32)), \
+		    memcpy(answer, &num, sizeof(afs_int32)), \
 		    answer += sizeof(afs_int32)
 
 #define getstr(name) if ((slen = strlen(packet)) >= sizeof(name)) return -1;\
 		     strcpy (name, packet), packet += slen+1
-#define getint(num) bcopy (packet, &num, sizeof(afs_int32)), \
+#define getint(num) memcpy(&num, packet, sizeof(afs_int32)), \
 		    num = ktohl (byteOrder, num), \
 		    packet += sizeof(afs_int32)
 
@@ -100,7 +100,6 @@ int fiveminutes=300;
 
 static FiveMinuteCheckLWP()
 {
-    	struct timeval time;
 
 	printf("start 5 min check lwp\n");
 
@@ -139,7 +138,7 @@ static afs_int32 create_cipher (cipher, cipherLen, sessionKey, sname, sinst,
     if (ticketLen > 255) return KAANSWERTOOLONG;
     if (kvno > 255) return KAANSWERTOOLONG;
 
-    bcopy (sessionKey, answer, sizeof(*sessionKey));
+    memcpy(answer, sessionKey, sizeof(*sessionKey));
     answer += sizeof(*sessionKey);
     putstr (sname);
     putstr (sinst);
@@ -147,7 +146,7 @@ static afs_int32 create_cipher (cipher, cipherLen, sessionKey, sname, sinst,
     *answer++ = life;
     *answer++ = (unsigned char) kvno;
     *answer++ = (unsigned char) ticketLen;
-    bcopy (ticket, answer, ticketLen);
+    memcpy(answer, ticket, ticketLen);
     answer += ticketLen;
     putint (start);
 
@@ -201,10 +200,10 @@ static afs_int32 create_reply (ans, name, inst, startTime, endTime, kvno,
     *answer++ = (unsigned char) kvno;
     {   short w = (short) cipherLen;
 	w = htons(w);
-	bcopy (&w, answer, sizeof(short));
+	memcpy(answer, &w, sizeof(short));
 	answer += sizeof(short);
     }
-    bcopy (cipher, answer, cipherLen);
+    memcpy(answer, cipher, cipherLen);
     return 0;
 }
 
@@ -322,7 +321,7 @@ afs_int32 UDP_Authenticate (ksoc, client, name, inst, startTime, endTime, sname,
 			startTime + ntohl(tentry.max_ticket_lifetime));
 	if ((code = ka_LookupKey (tt, sname, sinst, &tgskvno, &tgskey)) ||
 	    (code = tkt_MakeTicket (ticket, &ticketLen, &tgskey,
-				    name, inst, "",
+				    name, inst, lrealm,
 				    startTime, endTime, &sessionKey,
 				    htonl(client->sin_addr.s_addr), sname, sinst)))
 	    goto abort;
@@ -358,6 +357,7 @@ afs_int32 UDP_Authenticate (ksoc, client, name, inst, startTime, endTime, sname,
 	code = -1;
 	goto fail;
     }
+    KALOG(name, inst, sname, sinst, NULL, client->sin_addr.s_addr, LOG_AUTHENTICATE);
     osi_audit ( UDPAuthenticateEvent, 0, AUD_STR, name, AUD_STR, inst, AUD_END);
     return 0;
 
@@ -553,7 +553,7 @@ fail:
     return code;
 }
  
-static err_packet (ksoc, pkt, code, reason)
+static int err_packet (ksoc, pkt, code, reason)
   int ksoc;
   struct packet *pkt;
   afs_int32  code;
@@ -575,7 +575,7 @@ static err_packet (ksoc, pkt, code, reason)
 	3/* nulls */ + (2 * sizeof(afs_int32)) + strlen (buf) + 1;
     if (ans.len > sizeof(ans.data)) {
 	printf ("Answer packet too long\n");
-	return;
+	return -1;
     }
 
     *answer++ = (unsigned char) KRB_PROT_VERSION;
@@ -600,8 +600,10 @@ static err_packet (ksoc, pkt, code, reason)
 		    code, ans.len);
 	else perror ("err_packet: sendto");
     }
+    return 0;
 }
 
+int
 process_udp_auth (ksoc, pkt)
   int ksoc;
   struct packet *pkt;
@@ -631,9 +633,9 @@ process_udp_auth (ksoc, pkt)
     if ((strlen(realm) > 0) && (strcmp (realm, lrealm) != 0)) {
 	err_packet (ksoc, pkt, KERB_ERR_NONNULL_REALM,
 		    "null realm name not allowed");
-	return;
+	return -1;
     }
-    bcopy (packet, &startTime, sizeof(startTime));
+    memcpy(&startTime, packet, sizeof(startTime));
     packet += sizeof(startTime);
     startTime = ktohl (pkt->byteOrder, startTime);
     pkt->time = startTime;
@@ -643,13 +645,13 @@ process_udp_auth (ksoc, pkt)
     if (code < 0) {
 	err_packet (ksoc, pkt, KERB_ERR_BAD_LIFETIME,
 		    "requested ticket lifetime invalid");
-	return;
+	return -1;
     }
     getstr (sname);
     getstr (sinst);
     if ((packet - pkt->data) != pkt->len) {
 	err_packet (ksoc, pkt, KERB_ERR_PKT_LENGTH, "packet length inconsistent");
-	return;
+	return -1;
     }
     pkt->rest = packet;
     code = UDP_Authenticate (ksoc, &pkt->from, name, inst,
@@ -664,9 +666,10 @@ process_udp_auth (ksoc, pkt)
 	} else 
 	    err_packet (ksoc, pkt, code, (char *)error_message (code));
     }
-    return;
+    return 0;
 }
 
+int
 process_udp_appl (ksoc, pkt)
   int ksoc;
   struct packet *pkt;
@@ -688,24 +691,26 @@ process_udp_appl (ksoc, pkt)
     authLen = *(unsigned char *)packet++;
     if (ticketLen > sizeof(ticket)) {
 	err_packet (ksoc, pkt, KERB_ERR_TEXT_LENGTH, "ticket too long");
-	return;
+	return -1;
     }
-    bcopy (packet, ticket, ticketLen);
+    memcpy(ticket, packet, ticketLen);
     packet += ticketLen;
     if (authLen > sizeof(auth)) {
 	err_packet (ksoc, pkt, KERB_ERR_TEXT_LENGTH, "authenticator too long");
-	return;
+	return -1;
     }
-    bcopy (packet, auth, authLen);
+    memcpy(auth, packet, authLen);
     pkt->rest = packet + authLen;
     code = UDP_GetTicket (ksoc, pkt, kvno, realm, ticket, ticketLen, auth, authLen);
     if (code) {
 	if (code == KANOENT) code = KERB_ERR_PRINCIPAL_UNKNOWN;
 	err_packet (ksoc, pkt, code, (char*)error_message (code));
-	return;
+	return -1;
     }
+    return 0;
 }
 
+void
 process_udp_request (ksoc, pkt)
   int ksoc;
   struct packet *pkt;
@@ -825,7 +830,7 @@ afs_int32 init_krb_udp ()
     if (inited) return -1;
     inited = 1;
 
-    bzero (&taddr, sizeof(taddr));
+    memset(&taddr, 0, sizeof(taddr));
     krb4name = "kerberos4";
     sp = getservbyname(krb4name, "udp");
     taddr.sin_family = AF_INET;  /* added for NCR port */
