@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/test/test_rxkad_free.c,v 1.1.1.4 2001/07/14 22:22:21 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/test/test_rxkad_free.c,v 1.1.1.6 2001/09/20 06:15:03 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -140,7 +140,7 @@ static long Main (as, arock)
     
     if (as->parms[13].items) { /* if password specified */
 	strncpy (passwd, as->parms[13].items->data, sizeof(passwd));
-	bzero (as->parms[13].items->data, strlen (as->parms[13].items->data));
+	memset(as->parms[13].items->data, 0, strlen (as->parms[13].items->data));
     } else {
 	char msg[sizeof(name)+15];
 	if (as->parms[12].items) strcpy (msg, "Admin Password: ");
@@ -171,11 +171,11 @@ static long Main (as, arock)
 
     if (!doAuth) {
 	ka_StringToKey (passwd, cell, &key);
-	bzero (passwd, sizeof(passwd));
+	memset(passwd, 0, sizeof(passwd));
     }
     if (hostUsage) {
-	bzero (serversUse, sizeof(serversUse));
-	bzero (serversHost, sizeof(serversHost));
+	memset(serversUse, 0, sizeof(serversUse));
+	memset(serversHost, 0, sizeof(serversHost));
     }
 
     startTime = time(0);
@@ -340,12 +340,12 @@ int main(argc, argv)
     register struct cmd_syndesc *ts;
     long code;
 
-    initialize_u_error_table();
-    initialize_cmd_error_table();
-    initialize_rxk_error_table();
-    initialize_ktc_error_table();
-    initialize_acfg_error_table();
-    initialize_ka_error_table();
+    initialize_U_error_table();
+    initialize_CMD_error_table();
+    initialize_RXK_error_table();
+    initialize_KTC_error_table();
+    initialize_ACFG_error_table();
+    initialize_KA_error_table();
 
     ts = cmd_CreateSyntax (0, Main, 0, "Main program");
     /* 0 */ cmd_AddParm (ts, "-number", CMD_SINGLE, CMD_OPTIONAL,
