@@ -17,7 +17,7 @@
 #include <afs/param.h>
 #endif
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/user.c,v 1.1.1.6 2001/07/14 22:22:17 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/kauth/user.c,v 1.1.1.8 2001/09/20 06:15:02 hartmans Exp $");
 
 #if defined(UKERNEL)
 #include "../afs/sysincludes.h"
@@ -71,7 +71,7 @@ afs_int32 GetTickets (
     struct ktc_token token;
 
     code = ka_GetAuthToken (name, instance, realm, key, lifetime, pwexpires);
-    bzero (key, sizeof(*key));
+    memset(key, 0, sizeof(*key));
     if (code) return code;
     code = ka_GetAFSTicket (name, instance, realm, lifetime, flags);
     return code;
@@ -186,7 +186,7 @@ afs_int32 ka_UserAuthenticateGeneral (
     }
 #endif
 
-#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_USR_LINUX20_ENV) && !defined(AFS_FBSD_ENV)
+#if !defined(AFS_NT40_ENV) && !defined(AFS_LINUX20_ENV) && !defined(AFS_USR_LINUX20_ENV) && !defined(AFS_XBSD_ENV)
     /* handle smoothly the case where no AFS system calls exists (yet) */
     old = (int (*)())signal(SIGSYS, SIG_IGN);
 #endif
@@ -238,7 +238,7 @@ afs_int32 ka_UserAuthenticateGeneral (
 	    strncpy (pass8, password, 8);
 	    pass8[8] = 0;
 	    ka_StringToKey (pass8, realm, &key);
-	    bzero (pass8, sizeof(pass8));
+	    memset(pass8, 0, sizeof(pass8));
 	    code = GetTickets (name, instance, realm, &key, lifetime, 
 			       password_expires, dosetpag);
 	    if (code == 0) {
