@@ -14,10 +14,11 @@
 #include <string.h>
 #include <pwd.h>
 #include <unistd.h>
+#include <errno.h>
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/pam/afs_setcred.c,v 1.1.1.5 2001/07/14 22:23:12 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/pam/afs_setcred.c,v 1.1.1.6 2001/09/11 14:34:01 hartmans Exp $");
 
 #include <sys/param.h>
 #include <afs/kautils.h>
@@ -44,12 +45,15 @@ pam_sm_setcred(
     int origmask;
     int logmask = LOG_UPTO(LOG_INFO);
     int nowarn = 0;
-    int use_first_pass = 1; /* use the password passed in by auth */
+    int use_first_pass = 0; /* use the password passed in by auth */
     int try_first_pass = 0;
     int got_authtok = 0;
-    int ignore_root = 0;
-    int trust_root = 0;
+    int ignore_uid  = 0;
+    int no_unlog = 0;
+    uid_t ignore_uid_id = 0;
+    int refresh_token = 0;
     int set_expires = 0; /* the default is to not to set the env variable */
+    int use_klog = 0;
     int i;
     struct pam_conv *pam_convp = NULL;
     char my_password_buf[256];
@@ -83,11 +87,31 @@ pam_sm_setcred(
 	} else if (strcasecmp(argv[i], "try_first_pass") == 0) {
 	    try_first_pass = 1;
         } else if (strcasecmp(argv[i], "ignore_root"   ) == 0) {
-            ignore_root = 1;
-        } else if (strcasecmp(argv[i], "trust_root"   ) == 0) {
-            trust_root = 1;
-        } else if (strcasecmp(argv[i], "catch_su"   ) == 0) {
-            use_first_pass = 0;
+            ignore_uid = 1;
+	    ignore_uid_id = 0;
+	} else if (strcasecmp(argv[i], "ignore_uid"    ) == 0) {
+	    i++;
+	    if (i == argc) {
+                pam_afs_syslog(LOG_ERR, PAMAFS_IGNOREUID, "ignore_uid missing argument");
+		ignore_uid = 0;
+	    } else {
+	        ignore_uid = 1;
+	        ignore_uid_id = (uid_t) strtol(argv[i], (char**)NULL, 10);
+	        if ( (0 > ignore_uid_id) || (ignore_uid_id > IGNORE_MAX) ) {
+		        ignore_uid = 0;
+		        pam_afs_syslog(LOG_ERR, PAMAFS_IGNOREUID, argv[i]);
+                }
+	    }
+	} else if (strcasecmp(argv[i], "no_unlog") == 0) {
+	    no_unlog = 1;
+	} else if (strcasecmp(argv[i], "refresh_token" ) == 0) {
+	    refresh_token = 1;
+	} else if (strcasecmp(argv[i], "set_token" ) == 0) {
+	    ;
+	} else if (strcasecmp(argv[i], "dont_fork" ) == 0) {
+	    ;
+	} else if (strcasecmp(argv[i], "use_klog" ) == 0) {
+	    use_klog = 1;
 	} else if (strcasecmp(argv[i], "setenv_password_expires")==0) {
 	    set_expires = 1;
 	} else {
@@ -97,16 +121,18 @@ pam_sm_setcred(
 
     if (use_first_pass) try_first_pass = 0;
 
-    pam_afs_syslog(LOG_DEBUG, PAMAFS_OPTIONS, nowarn, use_first_pass, try_first_pass);
+    if (logmask && LOG_MASK(LOG_DEBUG))
+      pam_afs_syslog(LOG_DEBUG, PAMAFS_OPTIONS, nowarn, use_first_pass, try_first_pass, ignore_uid, ignore_uid_id, 8, 8, 8, 8);
     /* Try to get the user-interaction info, if available. */
-    errcode = pam_get_item(pamh, PAM_CONV, (void **) &pam_convp);
+    errcode = pam_get_item(pamh, PAM_CONV, (const void **) &pam_convp);
     if (errcode != PAM_SUCCESS) {
+      if (logmask && LOG_MASK(LOG_DEBUG))
 	pam_afs_syslog(LOG_DEBUG, PAMAFS_NO_USER_INT);
 	pam_convp = NULL;
     }
 
     /* Who are we trying to authenticate here? */
-    if ((errcode = pam_get_user(pamh, &user, "AFS username:")) != PAM_SUCCESS) {
+    if ((errcode = pam_get_user(pamh, (const char **)&user, "AFS username:")) != PAM_SUCCESS) {
         pam_afs_syslog(LOG_ERR, PAMAFS_NOUSER, errcode);
         RET(PAM_USER_UNKNOWN);
     }
@@ -115,6 +141,9 @@ pam_sm_setcred(
      * and its uid==0, and "ignore_root" was given in pam.conf,
      * ignore the user.
      */
+    /* enhanced: use "ignore_uid <number>" to specify the largest uid
+     * which should be ignored by this module
+     */
 #if	defined(AFS_HPUX_ENV)
 #if     defined(AFS_HPUX110_ENV)
     i = getpwnam_r(user, &unix_pwd, upwd_buf, sizeof(upwd_buf), &upwd);
@@ -123,38 +152,36 @@ pam_sm_setcred(
     if ( i == 0 )                       /* getpwnam_r success */
         upwd = &unix_pwd;
 #endif  /* AFS_HPUX110_ENV */
-    if (ignore_root && i == 0 && upwd->pw_uid == 0) {
+    if (ignore_uid && i == 0 && upwd->pw_uid <= ignore_uid_id) {
         pam_afs_syslog(LOG_INFO, PAMAFS_IGNORINGROOT, user);
         RET(PAM_AUTH_ERR);
     }
 #else
-#ifdef AFS_LINUX20_ENV
+#if     defined(AFS_LINUX20_ENV) || defined(AFS_FBSD_ENV)
     upwd = getpwnam(user);
 #else
     upwd = getpwnam_r(user, &unix_pwd, upwd_buf, sizeof(upwd_buf));
 #endif
-    if (upwd != NULL && upwd->pw_uid == 0) {
-	if (ignore_root) { 
+    if (ignore_uid && upwd != NULL && upwd->pw_uid <= ignore_uid_id) {
 		pam_afs_syslog(LOG_INFO, PAMAFS_IGNORINGROOT, user);
 		RET(PAM_AUTH_ERR);
-	} else if (trust_root) {
-		pam_afs_syslog(LOG_INFO, PAMAFS_TRUSTROOT, user);
-		RET(PAM_SUCCESS);
-	}
     }
 #endif
 
     if (flags & PAM_DELETE_CRED) {
+      if (logmask && LOG_MASK(LOG_DEBUG))
 	pam_afs_syslog(LOG_DEBUG, PAMAFS_DELCRED, user);
 
 	RET(PAM_SUCCESS);
     } else if (flags & PAM_REINITIALIZE_CRED) {
 
+      if (logmask && LOG_MASK(LOG_DEBUG))
         pam_afs_syslog(LOG_DEBUG, PAMAFS_REINITCRED, user);
         RET(PAM_SUCCESS);
 
     } else { /* flags are PAM_REFRESH_CRED, PAM_ESTABLISH_CRED, unknown */
 
+      if (logmask && LOG_MASK(LOG_DEBUG))
 	pam_afs_syslog(LOG_DEBUG, PAMAFS_ESTABCRED, user);
 
 	errcode = pam_get_data(pamh, pam_afs_lh, (const void **) &password);
@@ -164,7 +191,8 @@ pam_sm_setcred(
 		RET(PAM_AUTH_ERR);
 	    }
 	    password = NULL;	/* In case it isn't already NULL */
-	    pam_afs_syslog(LOG_DEBUG, PAMAFS_NOFIRSTPASS, user);
+	    if (logmask && LOG_MASK(LOG_DEBUG))
+	      pam_afs_syslog(LOG_DEBUG, PAMAFS_NOFIRSTPASS, user);
 	} else if (password[0] == '\0') {
 	    /* Actually we *did* get one but it was empty. */
 	    got_authtok = 1;
@@ -175,8 +203,10 @@ pam_sm_setcred(
 		pam_afs_syslog(LOG_ERR, PAMAFS_PASSWD_REQ, user);
 		RET(PAM_NEW_AUTHTOK_REQD);
 	    }
-	    pam_afs_syslog(LOG_DEBUG, PAMAFS_NILPASSWORD, user);
+	    if (logmask && LOG_MASK(LOG_DEBUG))
+	      pam_afs_syslog(LOG_DEBUG, PAMAFS_NILPASSWORD, user);
 	} else {
+	  if (logmask && LOG_MASK(LOG_DEBUG))
 	    pam_afs_syslog(LOG_DEBUG, PAMAFS_GOTPASS, user);
 	    torch_password = 0;
 	    got_authtok = 1;
@@ -206,6 +236,7 @@ pam_sm_setcred(
 		RET(PAM_AUTH_ERR);
 	    }
 	    if (password[0] == '\0') {
+	      if (logmask && LOG_MASK(LOG_DEBUG))
 		pam_afs_syslog(LOG_DEBUG, PAMAFS_NILPASSWORD);
 		RET(PAM_NEW_AUTHTOK_REQD);
 	    }
@@ -216,16 +247,30 @@ pam_sm_setcred(
 	     * this storage, copy it to a buffer that won't need to be freed
 	     * later, and free this storage now.
 	     */
+
 	    strncpy(my_password_buf, password, sizeof(my_password_buf));
 	    my_password_buf[sizeof(my_password_buf)-1] = '\0';
 	    memset(password, 0, strlen(password));
 	    free(password);
 	    password = my_password_buf;
 	}
+	/*
+	 * We only set a PAG here, if we haven't got one before in
+	 * pam_sm_authenticate() or if it was destroyed by the application
+	 */
+	if ((!refresh_token) && (getPAG() == -1)) {
+	  if (logmask && LOG_MASK(LOG_DEBUG))
+	    syslog(LOG_DEBUG, "New PAG created in pam_setcred()");
+	   setpag();
+	}
 
 	if ( flags & PAM_REFRESH_CRED ) {
+	    if (use_klog) {
+               auth_ok = do_klog(user, password, "00:00:01");
+	       ktc_ForgetAllTokens();
+	    } else {
             if ( ka_VerifyUserPassword(
-                           KA_USERAUTH_VERSION + KA_USERAUTH_DOSETPAG,
+                           KA_USERAUTH_VERSION,
                            user, /* kerberos name */
                            (char *)0, /* instance */
                            (char *)0, /* realm */
@@ -238,10 +283,13 @@ pam_sm_setcred(
 		auth_ok = 1;
 	    }	
 	}
+	}
 	    
 	if (  flags & PAM_ESTABLISH_CRED ) {
+	   if (use_klog) auth_ok = do_klog(user, password, NULL);
+	   else {
 	    if ( ka_UserAuthenticateGeneral(
-                           KA_USERAUTH_VERSION + KA_USERAUTH_DOSETPAG,
+                           KA_USERAUTH_VERSION,
                            user, /* kerberos name */
                            (char *)0, /* instance */
                            (char *)0, /* realm */
@@ -256,19 +304,22 @@ pam_sm_setcred(
 	       auth_ok = 1;
 	    }
 	}
+	}
 
 	if (!auth_ok && try_first_pass) {
 	    password = NULL;
 	    goto try_auth;
 	}
 
-	if (auth_ok && !got_authtok) {
-	    torch_password = 0;
-	    (void) pam_set_item(pamh, PAM_AUTHTOK, password);
-	}
+	/* pam_sm_authenticate should have set this 
+	 * if (auth_ok && !got_authtok) {
+	 *     torch_password = 0;
+	 *     (void) pam_set_item(pamh, PAM_AUTHTOK, password);
+         * }
+	 */
 
 	if (auth_ok) {
-	    if (set_expires &&  (password_expires >= 0) ) {
+	    if (set_expires && !use_klog &&  (password_expires >= 0) ) {
 		strcpy(sbuffer, "PASSWORD_EXPIRES=");
 		strcat(sbuffer, cv2string(&sbuffer[100], password_expires));
 		errcode = pam_putenv( pamh, sbuffer); 
@@ -276,14 +327,15 @@ pam_sm_setcred(
 		    pam_afs_syslog(LOG_ERR, PAMAFS_PASSEXPFAIL, user);
 	    }
 #if defined(AFS_KERBEROS_ENV)
-    	    if (upwd)
-    	    {
+    	    if (!use_klog) {
+               if (upwd) {
         	if ( chown(ktc_tkt_string(), upwd->pw_uid, upwd->pw_gid) < 0 )
 		    pam_afs_syslog(LOG_ERR, PAMAFS_CHOWNKRB, user);
 		sprintf(sbuffer, "KRBTKFILE=%s", ktc_tkt_string());
 		errcode = pam_putenv( pamh, sbuffer);
                 if ( errcode != PAM_SUCCESS )
                     pam_afs_syslog(LOG_ERR, PAMAFS_KRBFAIL, user);
+	       }
     	    }
 #endif
 
