@@ -12,7 +12,7 @@ extern int errno;
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ptserver/db_verify.c,v 1.1.1.5 2001/07/14 22:23:16 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ptserver/db_verify.c,v 1.1.1.7 2001/09/20 06:15:55 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -222,7 +222,6 @@ int PrintEntryError (misc, ea, e, indent)
   struct prentry *e;
   int indent;
 {
-    int i;
 
     pr_PrintEntry (stderr, /*net order*/0, ea, e, indent);
     return 0;
@@ -269,7 +268,7 @@ afs_int32 WalkHashTable (hashtable, hashType, map, misc)
 	    id = ntohl(e.id);
 
 	    if ( ((ntohl(e.flags) & (PRGRP | PRINST)) == 0) &&
-		 (index(e.name,'@')) ) {
+		 (strchr(e.name,'@')) ) {
 	       /* Foreign user */
 	       if (id > misc->maxForId) misc->maxForId = id;
 	    } else {
@@ -613,7 +612,7 @@ afs_int32 WalkChains (map, misc)
 	    if (code) return code;
 	    code = WalkNextChain (map, misc, ea, &e);
 	    if (code) return code;
-	    if (index(e.name,'@') == 0) {
+	    if (strchr(e.name,'@') == 0) {
 	        misc->nusers++;             /* Not a foreign user */
 	    } else {
 	        misc->nforeigns++;          /* A foreign user */
@@ -724,7 +723,7 @@ afs_int32 DumpRecreate (map, misc)
 
     rc = misc->recreate;
     idmap = misc->idmap;
-    bzero (idmap, misc->idRange*sizeof(misc->idmap[0]));
+    memset(idmap, 0, misc->idRange*sizeof(misc->idmap[0]));
     do {
 	found = 0;
 	for (ei=createLow; ei<misc->nEntries; ei++) {
@@ -927,7 +926,7 @@ afs_int32 CheckPrDatabase (misc)
     if (misc->verbose)
        printf ("Database has %d entries\n", n);
     map = (char *)malloc (n);
-    bzero (map, n);
+    memset(map, 0, n);
     misc->nEntries = n;
 
     if (misc->verbose) {
@@ -959,7 +958,7 @@ afs_int32 CheckPrDatabase (misc)
 	code = -1;
 	goto abort;
     }
-    bzero (misc->idmap, misc->idRange*sizeof(misc->idmap[0]));
+    memset(misc->idmap, 0, misc->idRange*sizeof(misc->idmap[0]));
 
     if (misc->verbose) {
        printf ("\nChecking entry chains\n");
@@ -1045,14 +1044,11 @@ WorkerBee (as, arock)
     char *recreateFile;
     struct misc_data misc;		/* info & statistics */
 
-    int   a;
-    char  arg[100];
-
-    initialize_pt_error_table();
-    initialize_u_error_table();
+    initialize_PT_error_table();
+    initialize_U_error_table();
     
     pr_dbaseName = AFSDIR_SERVER_PRDB_FILEPATH;
-    bzero (&misc, sizeof(misc));
+    memset(&misc, 0, sizeof(misc));
 
     pr_dbaseName     =  as->parms[0].items->data;        /* -database */
     misc.listuheader = (as->parms[1].items ? 1 : 0);     /* -uheader  */
@@ -1099,7 +1095,6 @@ main (argc, argv)
   char *argv[];
 {
   struct cmd_syndesc *ts;
-  struct cmd_item    *ti;
 
   setlinebuf(stdout);
 
