@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_getaddr.c,v 1.1.1.6 2001/07/14 22:23:28 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_getaddr.c,v 1.1.1.7 2001/09/20 06:16:03 hartmans Exp $");
 
 #ifndef AFS_DJGPP_ENV
 #ifndef KERNEL
@@ -21,7 +21,7 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_getaddr.c
 #include <net/if.h>
 #include <netinet/in.h>
 #include <sys/ioctl.h>
-#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 #include <sys/sysctl.h>
 #include <net/route.h>
 #include <net/if_dl.h>
@@ -108,7 +108,7 @@ afs_int32 rxi_getaddr ()
 #undef socket
 #endif /* UKERNEL */
 
-#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 #define ROUNDUP(a) \
         ((a) > 0 ? (1 + (((a) - 1) | (sizeof(long) - 1))) : sizeof(long))
 #define ADVANCE(x, n) (x += ROUNDUP((n)->sa_len))
@@ -135,7 +135,7 @@ rt_xaddrs(cp, cplim, rtinfo)
 /* this function returns the total number of interface addresses 
 ** the buffer has to be passed in by the caller
 */
-#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 int rx_getAllAddr (buffer,maxSize)
 afs_int32	buffer[];
 int 	maxSize;	/* sizeof of buffer in afs_int32 units */
@@ -342,13 +342,13 @@ int    maxSize;        /* sizeof of buffer in afs_int32 units */
     len = ifc.ifc_len / sizeof(struct ifreq);
     if (len > NIFS)
 	len = NIFS;
-#if    defined(AFS_AIX41_ENV) || defined (AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if    defined(AFS_AIX41_ENV) || defined (AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
     if ( ifc.ifc_len > sizeof(ifs) ) 	/* safety check */
 	ifc.ifc_len = sizeof(ifs); 
     for ( cp = (char *)ifc.ifc_buf, 
 		cplim= ifc.ifc_buf+ifc.ifc_len;
 		cp < cplim;
-#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+#if defined(AFS_DARWIN_ENV) || defined(AFS_XBSD_ENV)
 	        cp += _SIZEOF_ADDR_IFREQ(*ifr))
 #else
                 cp += sizeof(ifr->ifr_name) + MAX(a->sin_len, sizeof(*a)))
