@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_pthread.c,v 1.1.1.6 2001/07/14 22:23:34 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/rx_pthread.c,v 1.1.1.7 2001/09/20 06:16:06 hartmans Exp $");
 
 #include <sys/types.h>
 #include <errno.h>
@@ -207,12 +207,6 @@ struct rx_call **newcallp;
     u_long host;
     u_short port;
     register struct rx_packet *p = (struct rx_packet *)0;
-    unsigned long rfds;
-    register unsigned long rrfds;
-    struct clock cv;
-    long nextPollTime;		/* time to next poll FD before sleeping */
-    int lastPollWorked, doingPoll;	/* true iff last poll was useful */
-    struct timeval tv, *tvp;
 
     assert(pthread_mutex_lock(&listener_mutex)==0);
     while (!listeners_started) {
@@ -378,6 +372,7 @@ rxi_Listen(sock)
 	exit(1);
     }
     AFS_SIGSET_RESTORE();
+    return 0;
 }
 
 
@@ -415,4 +410,5 @@ rxi_Sendmsg(socket, msg_p, flags)
 	printf("rxi_sendmsg failed, error %d\n", errno);
 	fflush(stdout);
     }
+    return 0;
 }
