@@ -29,7 +29,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/xdr_arrayn.c,v 1.1.1.3 2001/07/14 22:23:37 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/xdr_arrayn.c,v 1.1.1.4 2001/09/11 14:34:26 hartmans Exp $");
 
 #if !defined(NeXT)
 
@@ -46,7 +46,9 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/rx/xdr_arrayn.c
 #include <sys/param.h>
 #ifdef AFS_LINUX20_ENV
 #include "../h/string.h"
+#if 0
 #define bzero(A,C) memset((A), 0, (C))
+#endif
 #else
 #include <sys/systm.h>
 #endif
@@ -112,7 +114,7 @@ bool_t xdr_arrayN(xdrs, addrp, sizep, maxsize, elsize, elproc)
 			if (target == NULL) {
 				return (FALSE);
 			}
-			bzero(target, (u_int)nodesize);
+			memset(target, 0, (u_int)nodesize);
 			break;
 
 		case XDR_FREE:
