@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ubik/disk.c,v 1.1.1.4 2001/07/14 22:24:06 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ubik/disk.c,v 1.1.1.6 2001/09/20 06:16:28 hartmans Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -80,7 +80,7 @@ udisk_Debug(aparm)
     struct buffer *tb;
     int i;
 
-    bcopy(&ubik_dbase->version, &aparm->localVersion, sizeof(struct ubik_version));
+    memcpy(&aparm->localVersion, &ubik_dbase->version, sizeof(struct ubik_version));
     aparm->lockedPages = 0;
     aparm->writeLockedPages = 0;
     tb = Buffers;
@@ -217,7 +217,7 @@ static int DInit (abuffers)
     int i;
     struct buffer *tb;
     Buffers = (struct buffer *) malloc(abuffers * sizeof(struct buffer));
-    bzero(Buffers, abuffers * sizeof(struct buffer));
+    memset(Buffers, 0, abuffers * sizeof(struct buffer));
     BufferData = (char *) malloc(abuffers * PAGESIZE);
     nbuffers = abuffers;
     for(i=0;i<PHSIZE;i++) phTable[i] = 0;
@@ -236,11 +236,11 @@ static int DInit (abuffers)
 }
 
 /* Take a buffer and mark it as the least recently used buffer */
-static int Dlru(abuf)
+static void Dlru(abuf)
   struct buffer *abuf;
 {
   if (LruBuffer == abuf)
-     return 0;
+     return;
 
   /* Unthread from where it is in the list */
   abuf->lru_next->lru_prev = abuf->lru_prev;
@@ -256,12 +256,12 @@ static int Dlru(abuf)
 }
 
 /* Take a buffer and mark it as the most recently used buffer */
-static int Dmru(abuf)
+static void Dmru(abuf)
      struct buffer *abuf;
 {
   if (LruBuffer == abuf) {
      LruBuffer = LruBuffer->lru_next;
-     return 0;
+     return;
   }
 
   /* Unthread from where it is in the list */
@@ -273,7 +273,6 @@ static int Dmru(abuf)
   abuf->lru_prev = LruBuffer->lru_prev;
   LruBuffer->lru_prev->lru_next = abuf;
   LruBuffer->lru_prev = abuf;
-
 }
 
 /* get a pointer to a particular buffer */
@@ -283,7 +282,7 @@ static char *DRead(dbase, fid, page)
     int page; {
     /* Read a page from the disk. */
     struct buffer *tb, *lastbuffer;
-    afs_int32 trys, code;
+    afs_int32 code;
 
     calls++;
     lastbuffer = LruBuffer->lru_prev;
@@ -306,7 +305,7 @@ static char *DRead(dbase, fid, page)
     /* can't find it */
     tb = newslot(dbase, fid, page);
     if (!tb) return 0;
-    bzero(tb->data, PAGESIZE);
+    memset(tb->data, 0, PAGESIZE);
 
     tb->lockers++;
     code = (*dbase->read)(dbase, fid, tb->data, page*PAGESIZE, PAGESIZE);
@@ -469,7 +468,7 @@ static struct buffer *newslot (adbase, afid, apage)
 }
 
 /* Release a buffer, specifying whether or not the buffer has been modified by the locker. */
-static DRelease (ap,flag)
+static void DRelease (ap,flag)
     char *ap;
     int flag; {
     int index;
@@ -480,7 +479,7 @@ static DRelease (ap,flag)
     bp = &(Buffers[index]);
     bp->lockers--;
     if (flag) bp->dirty=1;
-    return 0;
+    return;
 }
 
 /* flush all modified buffers, leaves dirty bits set (they're cleared
@@ -558,7 +557,7 @@ static char *DNew (dbase, fid, page)
 
     if ((tb = newslot(dbase, fid, page)) == 0) return (char *) 0;
     tb->lockers++;
-    bzero(tb->data, PAGESIZE);
+    memset(tb->data, 0, PAGESIZE);
     return tb->data;
 }
 
@@ -582,7 +581,7 @@ udisk_read(atrans, afile, abuffer, apos, alen)
 	offset = apos & (PAGESIZE-1);
 	len = PAGESIZE - offset;
 	if (len > alen) len = alen;
-	bcopy(bp+offset, abuffer, len);
+	memcpy(abuffer, bp+offset, len);
 	abuffer += len;
 	apos += len;
 	alen -= len;
@@ -658,13 +657,13 @@ udisk_write(atrans, afile, abuffer, apos, alen)
 	if (!bp) {
 	    bp = DNew(dbase, afile, apos>>LOGPAGESIZE);
 	    if (!bp) return UIOERROR;
-	    bzero(bp, PAGESIZE);
+	    memset(bp, 0, PAGESIZE);
 	}
 	/* otherwise, min of remaining bytes and end of buffer to user mode */
 	offset = apos & (PAGESIZE-1);
 	len = PAGESIZE-offset;
 	if (len > alen) len = alen;
-	bcopy(abuffer, bp+offset, len);
+	memcpy(bp+offset, abuffer, len);
 	abuffer += len;
 	apos += len;
 	alen -= len;
@@ -694,7 +693,7 @@ udisk_begin(adbase, atype, atrans)
 	if (code) return code;
     }
     tt = (struct ubik_trans *) malloc(sizeof(struct ubik_trans));
-    bzero(tt, sizeof(struct ubik_trans));
+    memset(tt, 0, sizeof(struct ubik_trans));
     tt->dbase = adbase;
     tt->next = adbase->activeTrans;
     adbase->activeTrans = tt;
