@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ubik/ubik.c,v 1.1.1.6 2001/07/14 22:24:08 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/ubik/ubik.c,v 1.1.1.8 2001/09/20 06:16:30 hartmans Exp $");
 
 #include <sys/types.h>
 #ifdef AFS_NT40_ENV
@@ -216,14 +216,14 @@ int ubik_ServerInitCommon(myHost, myPort, info, clones, serverList, pathName, db
     extern void rx_ServerProc();
     extern int rx_stackSize;
 
-    initialize_u_error_table();
+    initialize_U_error_table();
 
     tdb = (struct ubik_dbase *) malloc(sizeof(struct ubik_dbase));
     tdb->pathName = (char *) malloc(strlen(pathName)+1);
     strcpy(tdb->pathName, pathName);
     tdb->activeTrans = (struct ubik_trans *) 0;
-    bzero(&tdb->version, sizeof(struct ubik_version));
-    bzero(&tdb->cachedVersion, sizeof(struct ubik_version));
+    memset(&tdb->version, 0, sizeof(struct ubik_version));
+    memset(&tdb->cachedVersion, 0, sizeof(struct ubik_version));
     Lock_Init(&tdb->versionLock);
     tdb->flags = 0;
     tdb->read = uphys_read;
@@ -399,7 +399,7 @@ int ubik_AbortTrans(transPtr)
     
     dbase = transPtr->dbase;
     DBHOLD(dbase);
-    bzero(&dbase->cachedVersion, sizeof(struct ubik_version));
+    memset(&dbase->cachedVersion, 0, sizeof(struct ubik_version));
     /* see if we're still up-to-date */
     if (!urecovery_AllBetter(dbase, transPtr->flags & TRREADANY)) {
 	udisk_abort(transPtr);
@@ -451,7 +451,7 @@ int ubik_EndTrans(transPtr)
 
     dbase = transPtr->dbase;
     DBHOLD(dbase);
-    bzero(&dbase->cachedVersion, sizeof(struct ubik_version));
+    memset(&dbase->cachedVersion, 0, sizeof(struct ubik_version));
 
     /* give up if no longer current */
     if (!urecovery_AllBetter(dbase, transPtr->flags & TRREADANY)) {
@@ -530,7 +530,7 @@ int ubik_EndTrans(transPtr)
   success:
     udisk_end(transPtr);
     /* update version on successful EndTrans */
-    bcopy(&dbase->version, &dbase->cachedVersion, sizeof(struct ubik_version));
+    memcpy(&dbase->cachedVersion, &dbase->version, sizeof(struct ubik_version));
     
     DBRELE(dbase);
     return 0;
@@ -667,9 +667,7 @@ int ubik_Write(transPtr, buffer, length)
     iovec[transPtr->iovec_info.iovec_wrt_len].position = transPtr->seekPos;
     iovec[transPtr->iovec_info.iovec_wrt_len].length   = length;
     
-    bcopy(buffer, 
-	  &transPtr->iovec_data.iovec_buf_val[transPtr->iovec_data.iovec_buf_len],
-	  length);
+    memcpy(&transPtr->iovec_data.iovec_buf_val[transPtr->iovec_data.iovec_buf_len], buffer, length);
 
     transPtr->iovec_info.iovec_wrt_len++;
     transPtr->iovec_data.iovec_buf_len += length;
