@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/usd/usd_file.c,v 1.1.1.6 2001/07/14 22:24:12 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/usd/usd_file.c,v 1.1.1.8 2001/09/20 06:16:33 hartmans Exp $");
 
 #include <errno.h>
 #include <fcntl.h>
@@ -26,7 +26,7 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/usd/usd_file.c,
 #endif
 #include <sys/mtio.h>
 #endif /* AFS_AIX_ENV */
-#ifdef AFS_DUX40_ENV
+#if defined(AFS_DUX40_ENV) || defined(AFS_OBSD_ENV)
 #include <sys/ioctl.h>
 #endif
 #include <afs/debug.h>
@@ -357,7 +357,7 @@ static int usd_FileOpen(
 	return errno;
 
     usd = (usd_handle_t) malloc(sizeof(*usd));
-    bzero(usd, sizeof(*usd));
+    memset(usd, 0, sizeof(*usd));
     usd->handle = (void *)fd;
     usd->read = usd_FileRead;
     usd->write = usd_FileWrite;
@@ -427,7 +427,7 @@ static int usd_FileStandardInput(
 	*usdP = NULL;
 
     usd = (usd_handle_t) malloc(sizeof(*usd));
-    bzero(usd, sizeof(*usd));
+    memset(usd, 0, sizeof(*usd));
     usd->handle = (void *)((unsigned long)0);
     usd->read = usd_FileRead;
     usd->write = usd_FileWrite;
@@ -455,7 +455,7 @@ static int usd_FileStandardOutput(
 	*usdP = NULL;
 
     usd = (usd_handle_t) malloc(sizeof(*usd));
-    bzero(usd, sizeof(*usd));
+    memset(usd, 0, sizeof(*usd));
     usd->handle = (void *)((unsigned long)1);
     usd->read = usd_FileRead;
     usd->write = usd_FileWrite;
