@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vlserver/vlclient.c,v 1.1.1.4 2001/07/14 22:24:51 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vlserver/vlclient.c,v 1.1.1.6 2001/09/20 06:16:56 hartmans Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -51,6 +51,16 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vlserver/vlclie
 #include "vlserver.h"
 #include "vlclient.h"
 
+void fill_listattributes_entry();
+void display_listattributes_entry();
+void display_entry();
+void display_entryN();
+void display_update_entry();
+void dump_stats();
+void GetArgs();
+void print_usage();
+void fill_entry();
+void fill_update_entry();
 
 extern int VL_GetAddrsU(), VL_RegisterAddrs();
 #define	VL_NUMBER_OPCODESX	34
@@ -243,7 +253,7 @@ char *aname; {
     }
     th = gethostbyname(aname);
     if (!th) return 0;
-    bcopy(th->h_addr, &addr, sizeof(addr));
+    memcpy(&addr, th->h_addr, sizeof(addr));
     return addr;
 }
 
@@ -253,7 +263,7 @@ static handleit(as)
 {
     register struct cmd_item *ti;
     register afs_int32 code, server = 0, sawserver=0;
-    afs_int32 i, id, voltype;
+    afs_int32 id, voltype;
     struct vldbentry entry;    
     char *cmd = 0, *cellp=0;
     struct VldbUpdateEntry updateentry;
@@ -297,9 +307,9 @@ static handleit(as)
     while (1) {
 	char line[500];
 	int nargs, releasetype;
-	bzero(&entry, sizeof(entry));
-	bzero(&updateentry, sizeof(updateentry));
-	bzero(&listbyattributes, sizeof(listbyattributes));
+	memset(&entry, 0, sizeof(entry));
+	memset(&updateentry, 0, sizeof(updateentry));
+	memset(&listbyattributes, 0, sizeof(listbyattributes));
 	printf("vl> ");
 	if (fgets(line, 499, stdin) == NULL) {
 	    printf("\n");
@@ -346,7 +356,7 @@ static handleit(as)
 	    } else if (!strcmp(oper,"ls")) {
 		 afs_int32 index, count, next_index;
 		 for (index = 0; 1; index = next_index) {
-		     bzero(&entry, sizeof(entry));
+		     memset(&entry, 0, sizeof(entry));
 		     code = ubik_Call(VL_ListEntry,cstruct,0,index,&count,&next_index,&entry);
 		     if (code) {
 			 printf("VL_ListEntry returned code = %d\n", code);
@@ -366,7 +376,7 @@ static handleit(as)
 		 }
 		 printf("Enumerating all entries in vldb...\n");
 		 for (index = 0; 1; index = next_index) {
-		     bzero(&entry, sizeof(entry));
+		     memset(&entry, 0, sizeof(entry));
 		     code = ubik_Call(VL_ListEntry,cstruct,0,index,&count,&next_index,&entry);
 		     if (code) {
 			 printf("VL_ListEntry returned code = %d\n", code);
@@ -395,7 +405,6 @@ static handleit(as)
 	    } else if (!strcmp(oper,"checkhash")) {
 		 int index, count, num=0, num1=0, num2 = 0, num3=0, num31=0, num4=0, num41=0, next_index;
 		 struct vldbentry tentry;    
-		 struct Vlent *vl1;    
 
 		 VL = SVL = (struct Vlent *) malloc(ALLOCNT * sizeof(struct Vlent));
 		 if (VL == NULL) {
@@ -404,7 +413,7 @@ static handleit(as)
 		 }
 		 printf("Volumes not found in main hash tables in vldb...\n");
 		 for (index = 0; 1; index = next_index) {
-		     bzero(&entry, sizeof(entry));
+		     memset(&entry, 0, sizeof(entry));
 		     code = ubik_Call(VL_ListEntry,cstruct,0,index,&count,&next_index,&entry);
 		     if (code) {
 			 printf("VL_ListEntry returned code = %d\n", code);
@@ -448,7 +457,6 @@ static handleit(as)
 	    } else if (!strcmp(oper,"fixhash")) {
 		 int index, count, num=0, num1=0, num2 = 0, next_index, x=0;
 		 struct vldbentry tentry;    
-		 struct Vlent *vl1;    
 
 		 VL = SVL = (struct Vlent *) malloc(ALLOCNT * sizeof(struct Vlent));
 		 if (VL == NULL) {
@@ -456,10 +464,10 @@ static handleit(as)
 		     exit(1);
 		 }
 		 printf("Volumes not found in main hash tables in vldb will be fixed...\n");
-		 bzero(&updateentry, sizeof(updateentry));
+		 memset(&updateentry, 0, sizeof(updateentry));
 		 for (index = 0; 1; index = next_index) {
 		     int n1=0, n2=0, n3=0, n4=0;
-		     bzero(&entry, sizeof(entry));
+		     memset(&entry, 0, sizeof(entry));
 		     code = ubik_Call(VL_ListEntry,cstruct,0,index,&count,&next_index,&entry);
 		     if (code) {
 			 printf("VL_ListEntry returned code = %d\n", code);
@@ -531,7 +539,7 @@ static handleit(as)
 		bulkentries entries;
 		struct vldbentry *entry;
 
-		bzero(&entries,sizeof(entries));
+		memset(&entries, 0, sizeof(entries));
 		fill_listattributes_entry(&listbyattributes, argp, nargs);
 		display_listattributes_entry(&listbyattributes, 0);
 		code = ubik_Call(VL_ListAttributes, cstruct, 0, &listbyattributes, &nentries, &entries);
@@ -563,7 +571,7 @@ static handleit(as)
 
 		for (si=0; si!=-1; si=nsi) {
 		   nentries = 0;
-		   bzero(&entries,sizeof(entries));
+		   memset(&entries, 0, sizeof(entries));
 		   code = ubik_Call(VL_ListAttributesN2, cstruct, 0, 
 				    &listbyattributes, name, si, 
 				    &nentries, &entries, &nsi);
@@ -586,7 +594,7 @@ static handleit(as)
 
 		fill_listattributes_entry(&listbyattributes, argp, nargs);
 		display_listattributes_entry(&listbyattributes, 0);
-		bzero(&linkedvldbs, sizeof(vldb_list));
+		memset(&linkedvldbs, 0, sizeof(vldb_list));
 		code = ubik_Call(VL_LinkedList, cstruct, 0, &listbyattributes,
 				 &netries, &linkedvldbs);
 		if (code) {
@@ -606,7 +614,7 @@ static handleit(as)
 
 		fill_listattributes_entry(&listbyattributes, argp, nargs);
 		display_listattributes_entry(&listbyattributes, 0);
-		bzero(&linkedvldbs, sizeof(vldb_list));
+		memset(&linkedvldbs, 0, sizeof(vldb_list));
 		code = ubik_Call(VL_LinkedListN, cstruct, 0, &listbyattributes,
 				 &netries, &linkedvldbs);
 		if (code) {
@@ -632,7 +640,7 @@ static handleit(as)
 		 sscanf(&(*argp)[0], "%d", &voltype);
 		 code = ubik_Call(VL_GetEntryByID, cstruct, 0, id, voltype, &entry);
 		 display_entry(&entry, code);
-		 bzero(&updateentry, sizeof(updateentry));
+		 memset(&updateentry, 0, sizeof(updateentry));
 		 updateentry.Mask = VLUPDATE_VOLNAMEHASH;
 		 printf("\tRehashing namehash table for %s (%d)\n", entry.name, entry.volumeId[RWVOL]);
 		 code = ubik_Call(VL_UpdateEntry, cstruct, 0, entry.volumeId[RWVOL], -1, &updateentry, 0);
@@ -643,7 +651,7 @@ static handleit(as)
 	     } else if (!strcmp(oper,"undelete")) {
 		 afs_int32 index, count, next_index;
 
-		 bzero(&updateentry, sizeof(updateentry));
+		 memset(&updateentry, 0, sizeof(updateentry));
 		 sscanf(&(*argp)[0], "%d", &id);
 		 ++argp, --nargs;
 		 sscanf(&(*argp)[0], "%d", &voltype);
@@ -653,7 +661,7 @@ static handleit(as)
 		 }
 		 printf("Searching vldb for volume %d...\n", id);
 		 for (index = 0; 1; index = next_index) {
-		     bzero(&entry, sizeof(entry));
+		     memset(&entry, 0, sizeof(entry));
 		     code = ubik_Call(VL_ListEntry,cstruct,0,index,&count,&next_index,&entry);
 		     if (code) {
 			 printf("VL_ListEntry returned code = %d\n", code);
@@ -700,7 +708,6 @@ static handleit(as)
 		int nentries, i;
 		afs_uint32 *addrp;
 		bulkaddrs addrs;
-		struct vldbentry *entry;
 		struct VLCallBack vlcb;
 
 		addrs.bulkaddrs_val = 0;
@@ -775,7 +782,6 @@ static handleit(as)
 	       int nentries1, nentries2, i, j, x, y, unique, found;
 	       afs_uint32 *addrp1, *addrp2;
 	       bulkaddrs addrs1, addrs2;
-	       struct vldbentry *entry;
 	       struct VLCallBack vlcb;
 	       ListAddrByAttributes attrs;
 	       afsUUID uuid;
@@ -870,13 +876,12 @@ static handleit(as)
 		int i;
 		afs_uint32 *addrp, tad;
 		bulkaddrs addrs;
-		struct vldbentry *entry;
 		afsUUID uuid;
 
-		bzero(&uuid,sizeof(uuid));
+		memset(&uuid, 0, sizeof(uuid));
 		sscanf(&(*argp)[0], "%d", &i);
 		++argp, --nargs;
-		bcopy(&i, uuid.node, sizeof(i));
+		memcpy(uuid.node, &i, sizeof(i));
 
 		if (nargs < 0 || nargs > 16) {
 		    printf("Illegal # entries = %d\n", nargs);
@@ -899,7 +904,6 @@ static handleit(as)
 	       extern struct hostent *hostutil_GetHostByName();
 	       struct hostent *h1, *h2;
 	       afs_uint32 a1, a2;
-	       unsigned char n1[80], n2[80];
 
 	       printf("changing %s", *argp);
 	       h1 = hostutil_GetHostByName(&(*argp)[0]);
@@ -907,7 +911,7 @@ static handleit(as)
 		 printf("cmdebug: can't resolve address for host %s");
 		 continue;
 	       }
-	       bcopy((afs_int32 *)h1->h_addr, &a1, sizeof(afs_uint32));
+	       memcpy(&a1, (afs_int32 *)h1->h_addr, sizeof(afs_uint32));
 
 	       ++argp, --nargs;
 	       printf(" to %s\n", *argp);
@@ -916,7 +920,7 @@ static handleit(as)
 		 printf("cmdebug: can't resolve address for host %s", *argp);
 		 continue;
 	       }
-	       bcopy((afs_int32 *)h2->h_addr, &a2, sizeof(afs_uint32));
+	       memcpy(&a2, (afs_int32 *)h2->h_addr, sizeof(afs_uint32));
 
 	       printf("changing 0x%x to 0x%x\n", ntohl(a1), ntohl(a2));
 	       code = ubik_Call(VL_ChangeAddr, cstruct, 0, ntohl(a1), ntohl(a2));
@@ -926,7 +930,6 @@ static handleit(as)
 	       }
 	     } else if (!strcmp(oper,"caid")) {
 	       afs_uint32 a1, a2;
-	       unsigned char n1[80], n2[80];
 
 	       sscanf(&(*argp)[0], "%d", &a1);
 	       printf("changing %d (0x%x)", a1, a1);
@@ -972,6 +975,7 @@ main(argc, argv)
 }
 
 
+void
 fill_entry(entry, argp, nargs)
 struct vldbentry *entry;
 char **argp;
@@ -1008,7 +1012,7 @@ int nargs;
     sscanf(&(*argp)[0], "%d", &entry->cloneId);
 }
 
-
+void
 fill_update_entry(entry, argp, nargs)
 struct VldbUpdateEntry *entry;
 char **argp;
@@ -1076,7 +1080,7 @@ int nargs;
     }
  }
 
-
+void
 fill_listattributes_entry(entry, argp, nargs)
     struct VldbListByAttributes *entry;
     char **argp;
@@ -1109,6 +1113,7 @@ fill_listattributes_entry(entry, argp, nargs)
 	entry->Mask |= VLLIST_FLAG;
  }
 
+void
 display_listattributes_entry(entry, error)
 struct VldbListByAttributes *entry;
 int			    error;
@@ -1130,6 +1135,7 @@ int			    error;
 
 #define	volumetype_string(type) (type == RWVOL? "read/write":type == ROVOL? "readonly":type == BACKVOL? "backup":"unknown")
 
+void
 display_entry(entry, error)
 struct vldbentry    *entry;
 int		    error;
@@ -1145,6 +1151,7 @@ int		    error;
 	printf("%12u\t%10d\t%10x\n", entry->serverNumber[i], entry->serverPartition[i], entry->serverFlags[i]);
 }
 
+void
 display_entryN(entry, error)
     struct nvldbentry *entry;
     int		      error;
@@ -1172,7 +1179,7 @@ display_entryN(entry, error)
      }
 }
 
-
+void
 display_update_entry(entry, error)
 struct VldbUpdateEntry	*entry;
 int			error;
@@ -1212,6 +1219,7 @@ int			error;
     }
 }
 
+void
 dump_stats(stats, vital_header)
 vldstats	*stats;
 vital_vlheader	*vital_header;
@@ -1230,6 +1238,7 @@ vital_vlheader	*vital_header;
 	printf("total %s entries=%d\n", volumetype_string(i), ntohl(vital_header->totalEntries[i]));
 }
 
+void
 GetArgs(line,args, nargs)
     register char *line;
     register char **args;
@@ -1250,6 +1259,7 @@ GetArgs(line,args, nargs)
     }
 }
 
+void
 print_usage()
 {
     printf("Valid Commands:\n");
