@@ -18,7 +18,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/clone.c,v 1.1.1.4 2001/07/14 22:24:54 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/clone.c,v 1.1.1.6 2001/09/20 06:16:58 hartmans Exp $");
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -76,6 +76,9 @@ struct clone_head {
     struct clone_items *last;
 };
 
+void CloneVolume();
+void CloneVolume_r();
+
 static ci_AddItem(ah, aino)
 Inode aino;
 struct clone_head *ah; {
@@ -107,7 +110,7 @@ struct clone_head *ah; {
 /* initialize a clone header */
 int ci_InitHead(struct clone_head *ah)
 {
-    bzero(ah, sizeof(*ah));
+    memset(ah, 0, sizeof(*ah));
     return 0;
 }
 
@@ -349,6 +352,7 @@ afs_int32 DoCloneIndex(rwvp, clvp, class, reclone)
    return error;
 }
 
+void
 CloneVolume(error, original, new, old)
     Error *error;
     Volume *original, *new, *old;
@@ -358,6 +362,7 @@ CloneVolume(error, original, new, old)
     VOL_UNLOCK
 }
 
+void
 CloneVolume_r(rerror, original, new, old)
     Error *rerror;
     Volume *original, *new, *old;
