@@ -16,7 +16,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/vnode.c,v 1.1.1.4 2001/07/14 22:25:01 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/vnode.c,v 1.1.1.6 2001/09/20 06:17:02 hartmans Exp $");
 
 #include <errno.h>
 #include <stdio.h>
@@ -60,6 +60,8 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/vnode.c,v 1
 struct VnodeClassInfo VnodeClassInfo[nVNODECLASSES];
 
 private int moveHash();
+void StickOnLruChain_r();
+void VPutVnode_r();
 
 #define BAD_IGET	-1000
 
@@ -183,7 +185,7 @@ VInitVnodes(class,nVnodes)
     }
 
     if (nVnodes == 0)
-	    return;
+	    return 0;
 
     va = (byte *) calloc(nVnodes,vcp->residentSize);
     assert (va != NULL);
@@ -214,6 +216,7 @@ VInitVnodes(class,nVnodes)
 	}
 	va += vcp->residentSize;
     }
+    return 0;
 }
 
 
@@ -360,7 +363,7 @@ Vnode *VAllocVnode_r(ec,vp,type)
 	LWP_CurrentProcess(&vnp->writer);
 #endif /* AFS_PTHREAD_ENV */
 	/* Sanity check:  is this vnode really not in use? */
-        { int n;
+        { 
 	  int size;
 	  IHandle_t *ihP = vp->vnodeIndex[class].handle;
 	  FdHandle_t *fdP;
@@ -382,7 +385,7 @@ Vnode *VAllocVnode_r(ec,vp,type)
 	  } else {
 	      /* growing file - grow in a reasonable increment */
 	      char *buf = (char *)malloc(16*1024);
-	      bzero(buf, 16*1024);
+	      memset(buf, 0, 16*1024);
 	      FDH_WRITE(fdP, buf, 16*1024);
 	      free(buf);
 	  }
@@ -398,7 +401,7 @@ Vnode *VAllocVnode_r(ec,vp,type)
 #else /* AFS_PTHREAD_ENV */
     LWP_CurrentProcess(&vnp->writer);
 #endif /* AFS_PTHREAD_ENV */
-    bzero(&vnp->disk, sizeof(vnp->disk));
+    memset(&vnp->disk, 0, sizeof(vnp->disk));
     vnp->changed_newTime = 0; /* set this bit when vnode is updated */
     vnp->changed_oldTime = 0; /* set this on CopyOnWrite. */
     vnp->delete = 0;
@@ -653,7 +656,7 @@ Vnode *VGetVnode_r(ec,vp,vnodeNumber,locktype)
 int  TrustVnodeCacheEntry = 1;
 /* This variable is bogus--when it's set to 0, the hash chains fill
    up with multiple versions of the same vnode.  Should fix this!! */
-
+void
 VPutVnode(ec,vnp)
     Error *ec;
     register Vnode *vnp;
@@ -663,6 +666,7 @@ VPutVnode(ec,vnp)
     VOL_UNLOCK
 }
 
+void
 VPutVnode_r(ec,vnp)
     Error *ec;
     register Vnode *vnp;
@@ -698,7 +702,7 @@ VPutVnode_r(ec,vnp)
 
 	    if (vnp->delete) {
 	        /* No longer any directory entries for this vnode. Free the Vnode */
-		bzero(&vnp->disk, sizeof (vnp->disk));
+		memset(&vnp->disk, 0, sizeof (vnp->disk));
 		mlkLastDelete = vnp->vnodeNumber;
 		/* delete flag turned off further down */
 		VNLog(202, 2, vnp->vnodeNumber, (afs_int32) vnp);
@@ -911,8 +915,10 @@ static int moveHash(vnp, newHash)
     vnp->hashNext = VnodeHashTable[newHash];
     VnodeHashTable[newHash] = vnp;
     vnp->hashIndex = newHash;
+    return 0;
 }
 
+void
 StickOnLruChain_r(vnp,vcp)
     register Vnode *vnp;
     register struct VnodeClassInfo *vcp;
