@@ -17,7 +17,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/vutil.c,v 1.1.1.5 2001/07/14 22:25:03 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/vutil.c,v 1.1.1.7 2001/09/20 06:17:04 hartmans Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -64,6 +64,11 @@ RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/vol/vutil.c,v 1
 #include <strings.h>
 #endif
 
+void AssignVolumeName();
+void AssignVolumeName_r();
+void ClearVolumeStats();
+void ClearVolumeStats_r();
+
 
 #define nFILES	(sizeof (stuff)/sizeof(struct stuff))
 
@@ -110,21 +115,17 @@ Volume *VCreateVolume_r(ec, partname, volumeId, parentId)
     			   no parent */
 {
     VolumeDiskData vol;
-    int fd, fd1, i;
+    int fd, i;
     char headerName[32], volumePath[64];
-    struct stat status;
     Device device;
     struct DiskPartition *partition;
     struct VolumeDiskHeader diskHeader;
-    int code;
     IHandle_t *handle;
     FdHandle_t *fdP;
     Inode nearInode=0; 
 
-    
-
     *ec = 0;
-    bzero(&vol, sizeof (vol));
+    memset(&vol, 0, sizeof (vol));
     vol.id = volumeId;
     vol.parentId = parentId;
     vol.copyDate = time(0);	/* The only date which really means when this
@@ -145,7 +146,7 @@ Volume *VCreateVolume_r(ec, partname, volumeId, parentId)
     nearInode %= partition->f_files;
 #endif
     VLockPartition(partname);
-    bzero(&tempHeader, sizeof (tempHeader));
+    memset(&tempHeader, 0, sizeof (tempHeader));
     tempHeader.stamp.magic = VOLUMEHEADERMAGIC;
     tempHeader.stamp.version = VOLUMEHEADERVERSION;
     tempHeader.id = vol.id;
@@ -279,6 +280,7 @@ Volume *VCreateVolume_r(ec, partname, volumeId, parentId)
 }
 
 
+void
 AssignVolumeName(vol, name, ext)
     register VolumeDiskData *vol;
     char *name,*ext;
@@ -288,6 +290,7 @@ AssignVolumeName(vol, name, ext)
     VOL_UNLOCK
 }
 
+void
 AssignVolumeName_r(vol, name, ext)
     register VolumeDiskData *vol;
     char *name,*ext;
@@ -317,7 +320,7 @@ afs_int32 CopyVolumeHeader_r(from, to)
     id = to->id;
     parent = to->parentId;
     copydate = to->copyDate;
-    bcopy(from, to, sizeof(*from));
+    memcpy(to, from, sizeof(*from));
     to->id = id;
     to->parentId = parent;
     to->copyDate = copydate;
@@ -338,6 +341,7 @@ afs_int32 CopyVolumeHeader(from, to)
     return(code);
 }
 
+void
 ClearVolumeStats(vol)
     register VolumeDiskData *vol;
 {
@@ -346,10 +350,11 @@ ClearVolumeStats(vol)
     VOL_UNLOCK
 }
 
+void
 ClearVolumeStats_r(vol)
     register VolumeDiskData *vol;
 {
-    bzero(vol->weekUse, sizeof(vol->weekUse));
+    memset(vol->weekUse, 0, sizeof(vol->weekUse));
     vol->dayUse = 0;
     vol->dayUseDate = 0;
 }
