@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/volser/dumpstuff.c,v 1.1.1.5 2001/07/14 22:25:07 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/volser/dumpstuff.c,v 1.1.1.7 2001/09/20 06:17:07 hartmans Exp $");
 
 #include <sys/types.h>
 #include <ctype.h>
@@ -205,7 +205,7 @@ static int ReadVolumeHeader(register struct iod *iodp, VolumeDiskData *vol)
 {
     register tag;
     afs_uint32 trash;
-    bzero(vol, sizeof(*vol));
+    memset(vol, 0, sizeof(*vol));
     while ((tag = iod_getc(iodp)) > D_MAX && tag != EOF) {
 	switch (tag) {
 	    case 'i':
@@ -417,7 +417,7 @@ static int DumpFile(struct iod *iodp, char tag, int vnode, FdHandle_t *handleP)
 {
     int   code = 0, lcode = 0, error = 0;
     afs_int32 pad = 0, offset;
-    int   n, nbytes, howMany;
+    int   n, nbytes, howMany, howBig;
     byte  *p;
     struct stat status;
     int size;
@@ -427,9 +427,13 @@ static int DumpFile(struct iod *iodp, char tag, int vnode, FdHandle_t *handleP)
 #endif
 
 #ifdef AFS_NT40_ENV
-    howMany = 4096; /* Page size */
+    howBig = _filelength(handleP->fd_fd);
+    howMany = 4096;
+
 #else
     fstat(handleP->fd_fd, &status);
+    howBig = status.st_size;
+
 #ifdef	AFS_AIX_ENV
     /* Unfortunately in AIX valuable fields such as st_blksize are 
      * gone from the stat structure.
@@ -438,9 +442,10 @@ static int DumpFile(struct iod *iodp, char tag, int vnode, FdHandle_t *handleP)
     howMany = tstatfs.f_bsize;
 #else
     howMany = status.st_blksize;
-#endif
+#endif /* AFS_AIX_ENV */
 #endif /* AFS_NT40_ENV */
 
+
     size = FDH_SIZE(handleP);
     code = DumpInt32(iodp, tag, size);
     if (code) {
@@ -488,9 +493,9 @@ static int DumpFile(struct iod *iodp, char tag, int vnode, FdHandle_t *handleP)
 	   /* Pad the rest of the buffer with zeros. Remember offset we started 
 	    * padding. Keep total tally of padding.
 	    */
-	   bzero(p+n, howMany-n);
+	   memset(p+n, 0, howMany-n);
 	   if (!pad)
-	      offset = (status.st_size - nbytes) + n;
+	      offset = (howBig - nbytes) + n;
 	   pad += (howMany-n);
 	   
 	   /* Now seek over the data we could not get. An error here means we
@@ -631,7 +636,6 @@ static int DumpVnodeIndex(register struct iod *iodp, Volume *vp,
     char buf[SIZEOF_LARGEDISKVNODE];
     struct VnodeDiskObject *vnode = (struct VnodeDiskObject *) buf;
     StreamHandle_t *file;
-    IHandle_t *handle;
     FdHandle_t *fdP;
     int size;
     int flag;
@@ -737,7 +741,7 @@ int ProcessIndex(Volume *vp, VnodeClass class, afs_int32 **Bufp, int *sizep,
     char buf[SIZEOF_LARGEDISKVNODE], zero[SIZEOF_LARGEDISKVNODE];
     register struct VnodeDiskObject *vnode = (struct VnodeDiskObject *) buf;
     
-    bzero(zero, sizeof(zero));	/* zero out our proto-vnode */
+    memset(zero, 0, sizeof(zero));	/* zero out our proto-vnode */
     fdP = IH_OPEN(vp->vnodeIndex[class].handle);
     if (fdP == NULL)
 	return -1;
@@ -782,7 +786,7 @@ int ProcessIndex(Volume *vp, VnodeClass class, afs_int32 **Bufp, int *sizep,
 	if (nVnodes > 0) {
 	    Buf = (afs_int32 *) malloc(nVnodes * sizeof(afs_int32));
 	    if (Buf == NULL) return 1;
-	    bzero((char *)Buf, nVnodes * sizeof(afs_int32));
+	    memset((char *)Buf, 0, nVnodes * sizeof(afs_int32));
 	    STREAM_SEEK(afile, offset = vcp->diskSize, 0);
 	    while (1) {
 		code = STREAM_READ(vnode, vcp->diskSize, 1, afile);
@@ -916,7 +920,7 @@ static int ReadVnodes(register struct iod *iodp, Volume *vp,
     V_pref(vp, nearInode);
     while (tag == D_VNODE) {
         int haveStuff = 0;
-	bzero(buf, sizeof (buf));
+	memset(buf, 0, sizeof (buf));
 	if (!ReadInt32(iodp, (afs_uint32 *)&vnodeNumber))
 	    break;
 
