@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/volser/volprocs.c,v 1.1.1.5 2001/07/14 22:25:09 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/volser/volprocs.c,v 1.1.1.7 2001/09/20 06:17:08 hartmans Exp $");
 
 #include <stdio.h>
 #include <sys/types.h>
@@ -190,7 +190,7 @@ Volume	* vp;
     int code;
     int length;
 
-    bzero(vnode, SIZEOF_LARGEDISKVNODE);    
+    memset(vnode, 0, SIZEOF_LARGEDISKVNODE);    
 
     V_pref(vp, nearInode);
     inodeNumber = IH_CREATE(V_linkHandle(vp), V_device(vp),
@@ -1146,7 +1146,7 @@ afs_int32 SAFSVolForwardMultiple (acid, fromTrans, fromDate, destinations,
   int i, nconns, is_incremental;
 
   if (results)
-     bzero(results, sizeof(manyResults));
+     memset(results, 0, sizeof(manyResults));
 
   if (!afsconf_SuperUser(tdir, acid, caller))
     return VOLSERBAD_ACCESS;/*not a super user*/
@@ -1584,13 +1584,15 @@ afs_int32 VolListPartitions (acid, partIds)
 struct rx_call *acid;
 struct pIDs *partIds;
 {   
-    struct stat rbuf, pbuf;
     char namehead[9];
+    struct stat rbuf, pbuf;
     int code;
     char i;
+
+    strcpy(namehead, "/vicep");	/*7 including null terminator*/
+
 #ifdef AFS_NT40_ENV
     /* Just return attached partitions. */
-    strcpy(namehead, "/vicep");
     namehead[7] = '\0';
     for (i=0; i<26; i++) {
 	namehead[6] = i + 'a';
@@ -1598,9 +1600,8 @@ struct pIDs *partIds;
 	    partIds->partIds[i] = VGetPartition(namehead, 0) ? i : -1;
     }
 #else
-    strcpy(namehead, "/vicep");	/*7 including null terminator*/
-    code = stat("/",&rbuf);	/*interested in buf->st_dev*/
     
+    (void) stat("/",&rbuf);	/*interested in buf->st_dev*/
    
     for(i = 0 ; i < 26 ; i++){
 	
@@ -1613,8 +1614,6 @@ struct pIDs *partIds;
 	    else  partIds->partIds[i ] = -1;
 	}
 	else partIds->partIds[i ] = -1;
-	
-	
     }
 #endif   
     return 0;
@@ -1659,7 +1658,7 @@ struct partEntries *pEntries;
 	    partList.partId[j++] = i;
     }
     pEntries->partEntries_val = (afs_int32 *) malloc(j * sizeof(int));
-    bcopy((char *)&partList, (char *)pEntries->partEntries_val, j * sizeof(int));
+    memcpy((char *)pEntries->partEntries_val, (char *)&partList, j * sizeof(int));
     pEntries->partEntries_len = j;
 #else
     code = stat("/",&rbuf);	/*interested in buf->st_dev*/
@@ -1680,7 +1679,7 @@ struct partEntries *pEntries;
 	}
     } 
     pEntries->partEntries_val = (afs_int32 *) malloc(j * sizeof(int));
-    bcopy((char *)&partList, (char *)pEntries->partEntries_val, j * sizeof(int));
+    memcpy((char *)pEntries->partEntries_val, (char *)&partList, j * sizeof(int));
     pEntries->partEntries_len = j;
 #endif
     return 0;
@@ -2049,9 +2048,7 @@ afs_int32 VolXListOneVolume (a_rxCidP, a_partID, a_volID, a_volumeXInfoP)
 	    /*
 	     * Copy out the stat fields in a single operation.
 	     */
-	    bcopy((char *)&(volDiskDataP->stat_reads[0]),
-		  (char *)&(xInfoP->stat_reads[0]),
-		  numStatBytes);
+	    memcpy((char *)&(xInfoP->stat_reads[0]), (char *)&(volDiskDataP->stat_reads[0]), numStatBytes);
 
 	    /*
 	     * We're done copying.  Detach the volume and iterate (at this
@@ -2445,9 +2442,7 @@ afs_int32 VolXListVolumes (a_rxCidP, a_partID, a_flags, a_volumeXInfoP)
 	    /*
 	     * Copy out the stat fields in a single operation.
 	     */
-	    bcopy((char *)&(volDiskDataP->stat_reads[0]),
-		  (char *)&(xInfoP->stat_reads[0]),
-		  numStatBytes);
+	    memcpy((char *)&(xInfoP->stat_reads[0]), (char *)&(volDiskDataP->stat_reads[0]), numStatBytes);
 
 	    /*
 	     * We're done copying.  Detach the volume and iterate.
