@@ -10,7 +10,7 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/volser/vsutils.c,v 1.1.1.6 2001/07/14 22:25:11 hartmans Exp $");
+RCSID("$Header: /afs/sipb/project/openafs/debian/cvs/openafs/src/volser/vsutils.c,v 1.1.1.8 2001/09/20 06:17:12 hartmans Exp $");
 
 #include <afs/stds.h>
 #ifdef AFS_NT40_ENV
@@ -57,7 +57,7 @@ static void ovlentry_to_nvlentry(oentryp, nentryp)
 {
     register int i;
 
-    bzero(nentryp, sizeof(struct nvldbentry));
+    memset(nentryp, 0, sizeof(struct nvldbentry));
     strncpy(nentryp->name, oentryp->name, sizeof(nentryp->name));
     for (i=0; i < oentryp->nServers; i++) {
 	nentryp->serverNumber[i] = oentryp->serverNumber[i];
@@ -77,7 +77,7 @@ static nvlentry_to_ovlentry(nentryp, oentryp)
 {
     register int i;
 
-    bzero(oentryp, sizeof(struct vldbentry));
+    memset(oentryp, 0, sizeof(struct vldbentry));
     strncpy(oentryp->name, nentryp->name, sizeof(oentryp->name));
     if (nentryp->nServers > OMAXNSERVERS) {
 	/*
@@ -105,7 +105,7 @@ VLDB_CreateEntry(entryp)
     struct nvldbentry *entryp;
 {
     struct vldbentry oentry;
-    register int code, (*nproc)();
+    register int code;
 
     if (newvlserver == 1) {
 tryold:
@@ -132,7 +132,7 @@ VLDB_GetEntryByID(volid, voltype, entryp)
     struct nvldbentry *entryp;
 {
     struct vldbentry oentry;
-    register int code, (*nproc)();
+    register int code;
 
     if (newvlserver == 1) {
 tryold:
@@ -158,7 +158,7 @@ VLDB_GetEntryByName(namep, entryp)
     struct nvldbentry *entryp;
 {
     struct vldbentry oentry;
-    register int code, (*nproc)();
+    register int code;
 
     if (newvlserver == 1) {
 tryold:
@@ -184,7 +184,7 @@ VLDB_ReplaceEntry(volid, voltype, entryp, releasetype)
     struct nvldbentry *entryp;
 {
     struct vldbentry oentry;
-    register int code, (*nproc)();
+    register int code;
 
     if (newvlserver == 1) {
 tryold:
@@ -218,7 +218,7 @@ VLDB_ListAttributes(attrp, entriesp, blkentriesp)
 
     if (newvlserver == 1) {
 tryold:
-	bzero(&arrayEntries, sizeof(arrayEntries)); /*initialize to hint the stub  to alloc space */
+	memset(&arrayEntries, 0, sizeof(arrayEntries)); /*initialize to hint the stub  to alloc space */
 	code = ubik_Call(VL_ListAttributes, cstruct, 0, attrp, entriesp, &arrayEntries);
 	if (!code) {
 	    blkentriesp->nbulkentries_val = (nvldbentry *)malloc(*entriesp * sizeof(struct nvldbentry));
@@ -270,8 +270,7 @@ extern int VL_GetAddrsU();
 VLDB_IsSameAddrs(serv1, serv2, errorp)
     afs_int32 serv1, serv2, *errorp;
 {
-    struct vldbentry oentry;
-    register int code, (*nproc)();
+    register int code;
     ListAddrByAttributes attrs;
     bulkaddrs addrs;
     afs_uint32 *addrp, nentries,  unique, i, j, f1, f2;
@@ -306,11 +305,11 @@ VLDB_IsSameAddrs(serv1, serv2, errorp)
 	  return 0;
   }
 
-    bzero(&attrs, sizeof(attrs));
+    memset(&attrs, 0, sizeof(attrs));
     attrs.Mask = VLADDR_IPADDR;
     attrs.ipaddr = serv1;
-    bzero(&addrs, sizeof(addrs));
-    bzero(&uuid, sizeof(uuid));
+    memset(&addrs, 0, sizeof(addrs));
+    memset(&uuid, 0, sizeof(uuid));
     code = ubik_Call(VL_GetAddrsU, cstruct, 0, &attrs, &uuid, &unique, &nentries, &addrs);
     if (vlserverv4 == -1) {
 	if (code == RXGEN_OPCODE) {
@@ -536,7 +535,7 @@ char *astring; {
     char *str,*ptr, volname[VOLSER_OLDMAXVOLNAME+1];
     int tryname, curval;
     struct nvldbentry entry;
-    afs_int32 vcode;
+    afs_int32 vcode = 0;
     int total;
 
     *errp = 0;
